#
# spec file for package ghc-lucid
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name lucid
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.11.20250303
Release:        1.2
Summary:        Clear to write, read and edit DSL for HTML
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-blaze-builder-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-mmorph-devel
BuildRequires:  ghc-mmorph-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-bifunctors-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
%endif

%description
Clear to write, read and edit DSL for HTML.

* Names are consistent, and do not conflict with base or are keywords (all have
suffix '_')

* Same combinator can be used for attributes and elements (e.g.
'style_')

* For more, read <https://chrisdone.com/posts/lucid the blog post>

See the "Lucid" module for more documentation.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Mar  3 2025 Peter Simons <psimons@suse.com>
- Update lucid to version 2.11.20250303.
  [#]# 2.11.20250303
  * Support GHC 9.12
* Thu Sep 19 2024 Peter Simons <psimons@suse.com>
- Update lucid to version 2.11.20230408 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Oct 29 2023 Peter Simons <psimons@suse.com>
- Update lucid to version 2.11.20230408 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Apr  8 2023 Peter Simons <psimons@suse.com>
- Update lucid to version 2.11.20230408.
  [#]# 2.11.20230408
  * Don't expect Control.Monad to be re-exported from mtl anymore
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Sep 27 2022 Peter Simons <psimons@suse.com>
- Update lucid to version 2.11.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun May  8 2022 Peter Simons <psimons@suse.com>
- Update lucid to version 2.11.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/lucid-2.11.1/src/CHANGELOG.md
* Wed Nov 10 2021 psimons@suse.com
- Update lucid to version 2.11.0 revision 1.
  [#]# 2.11.0
  * Change internal attributes to `Seq Attribute`. This preserves
    ordering. Attributes are merged in a left-biased way, preserving the
    key order as first encountered.
* Tue Oct 19 2021 psimons@suse.com
- Update lucid to version 2.10.0.
  [#]# 2.9.13
  * Change internal attributes representation from HashMap to Map. This
    introduces stable ordering, at a negligible performance cost for
    realistic element sizes. This may affect some test suites.
  * doctype no longer accepts attributes. You can use `with` with
    `doctypeHtml` now, if needed.
* Tue Mar  2 2021 psimons@suse.com
- Update lucid to version 2.9.12.1.
  [#]# 2.9.12.1
  * Allow different orderings of attributes in test-suite
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update lucid to version 2.9.12 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add lucid at version 2.9.12.
